pub enum CrossingDirection {
Rising,
Falling,
Both,
}Expand description
Direction of zero-crossing to detect.
Variants
Rising
Detect only when the event function goes from negative to positive
Falling
Detect only when the event function goes from positive to negative
Both
Detect crossings in either direction