pub struct SdeProblem<F, G>{
pub x0: Array1<f64>,
pub t_span: [f64; 2],
pub n_brownian: usize,
pub f_drift: F,
pub g_diffusion: G,
}Expand description
Defines a Stochastic Differential Equation problem of the form:
dx = f(t, x) dt + g(t, x) dW, x(t0) = x0where f is the drift coefficient, g is the diffusion matrix,
and dW is an m-dimensional Wiener process increment.
Type Parameters
F- drift function type:Fn(f64, &Array1<f64>) -> Array1<f64>G- diffusion function type:Fn(f64, &Array1<f64>) -> Array2<f64>
Fields
x0: Array1<f64>Initial state vector x(t0), dimension n
t_span: [f64; 2]Time span [t0, t1]
n_brownian: usizeNumber of independent Brownian motions (Wiener processes), m
f_drift: FDrift coefficient f(t, x): R × R^n → R^n
g_diffusion: GDiffusion matrix g(t, x): R × R^n → R^{n×m}
Implementations
Sourceimpl<F, G> SdeProblem<F, G>
impl<F, G> SdeProblem<F, G>
Sourcepub fn new(
x0: Array1<f64>,
t_span: [f64; 2],
n_brownian: usize,
f_drift: F,
g_diffusion: G,
) -> Self
pub fn new( x0: Array1<f64>, t_span: [f64; 2], n_brownian: usize, f_drift: F, g_diffusion: G, ) -> Self
Create a new SDE problem.
Arguments
x0- Initial state vector (length n)t_span- Time interval [t0, t1]n_brownian- Number of independent Brownian motionsf_drift- Drift function f(t, x) → R^ng_diffusion- Diffusion function g(t, x) → R^{n×m}
Errors
Returns an error if the time span is invalid (t0 >= t1).
Sourcepub fn validate(&self) -> IntegrateResult<()>
pub fn validate(&self) -> IntegrateResult<()>
Validate the problem parameters